@@ -1,5 +1,5 @@
 package Reply::Plugin::Prompt;
-$Reply::Plugin::Prompt::VERSION = '0.0.19.0';
+$Reply::Plugin::Prompt::VERSION = '0.0.20.0';
 use strict;
 use warnings;
 use Cwd qw(abs_path getcwd);
@@ -38,7 +38,7 @@ my $insert_time    = ' %s';
 my $time_format    = '%H:%M:%S';  # time format
 my $prompt_char    = '❯ ';        # prompt character
 my $wakatime_cmd =
-'wakatime-cli --write --plugin=repl-reply-wakatime --entity-type=app --entity=perl --alternate-language=perl --project=%s';
+'wakatime-cli --write --plugin=repl-reply-wakatime --entity-type=app --entity=perl --alternate-language=perl --project=%s &';
 
 sub new {
     my $class = shift;
@@ -230,7 +230,7 @@ Reply::Plugin::Prompt - reply plugin for powerlevel10k style prompt
 
 =head1 VERSION
 
-version 0.0.19.0
+version 0.0.20.0
 
 =head1 DESCRIPTION
 
@@ -281,4 +281,4 @@ F<${XDG_CONFIG_PATH:-$HOME/.config}/reply/prompt.pl>:
     $time_format    = '%H:%M:%S';  # time format
     $prompt_char    = '❯ ';        # prompt character
     $wakatime_cmd =
-    'wakatime-cli --write --plugin=repl-reply-wakatime --entity-type=app --entity=perl --alternate-language=perl --project=%s';
+    'wakatime-cli --write --plugin=repl-reply-wakatime --entity-type=app --entity=perl --alternate-language=perl --project=%s &';
